pub struct Fault {
pub function: String,
pub pc: Option<usize>,
pub what: String,
}Expand description
A way in which encoded bytes are not something that may be run.
Fields
function: StringThe function the fault is in, as module.name.
pc: Option<usize>The instruction it is at, or None when the fault is the run’s own —
a program and an encoding of different lengths, say.
what: StringTrait Implementations
impl Eq for Fault
impl StructuralPartialEq for Fault